#!/usr/bin/env node
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const path_1 = require("path");
const url_1 = require("url");
const yargs = __importStar(require("yargs"));
const FileZip_1 = __importDefault(require("../lib/FileZip"));
const PartialZip_1 = __importDefault(require("../lib/PartialZip"));
// Modified from https://stackoverflow.com/a/18650828/11131612
function bytesToSize(bytes) {
    const input = BigInt(bytes);
    const sizes = ['B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB'];
    // tslint:disable-next-line:triple-equals
    if (input === 0n)
        return '0 B';
    // TODO: Add math floor and logarithm
    // Math.floor seems to be done by default in BigInt divsion
    // So I only need to logarithm
    const i = Math.floor(Math.log(Number(bytes)) / Math.log(1000));
    return `${input / BigInt(1000 ** i)} ${sizes[i]}`;
}
const isUrl = (pathOrUrl) => ['http:', 'https:'].includes(url_1.parse(pathOrUrl).protocol || '');
async function list(argv) {
    const Zip = isUrl(argv.url) ? PartialZip_1.default : FileZip_1.default;
    const pz = new Zip(argv.url);
    await pz.init();
    pz.files.forEach((fileInfo, fileName) => {
        if (fileName.endsWith('/'))
            return;
        const { extraField, uncompressedSize } = fileInfo;
        const size = extraField.zip64 && extraField.zip64.uncompressedSize
            ? extraField.zip64.uncompressedSize
            : BigInt(uncompressedSize);
        // eslint-disable-next-line no-console
        console.log('%s\t%s', bytesToSize(size), fileName);
    });
}
async function download(argv) {
    const Zip = isUrl(argv.url) ? PartialZip_1.default : FileZip_1.default;
    const pz = new Zip(argv.url);
    await pz.init();
    const fileInfo = pz.files.get(argv.filename);
    if (!fileInfo)
        throw new Error('File Not Found');
    let output = path_1.resolve(argv.output ? argv.output : path_1.basename(fileInfo.fileName));
    if (fs_1.existsSync(output)) {
        const outputStat = fs_1.statSync(output);
        if (outputStat.isDirectory()) {
            output = path_1.join(argv.output, path_1.basename(fileInfo.fileName));
        }
        if (outputStat.isFile())
            throw new Error('File Exists');
    }
    const data = await pz.get(fileInfo);
    fs_1.writeFileSync(output, data);
}
// eslint-disable-next-line @typescript-eslint/no-unused-expressions
yargs
    .scriptName('partialzip')
    .usage('$0 <cmd> [args]')
    .showHelpOnFail(true)
    .command({
    command: 'list <url>',
    aliases: ['ls'],
    describe: 'List files in a Zip URL',
    builder(args) {
        return args.positional('url', {
            type: 'string',
            describe: 'Zip URL',
        });
    },
    handler: list,
})
    .command({
    command: 'download <url> <filename> [output]',
    aliases: ['dl'],
    describe: 'Download file from Zip URL',
    builder(args) {
        args.positional('url', {
            type: 'string',
            describe: 'Zip URL',
        });
        args.positional('filename', {
            type: 'string',
            describe: 'Filename of file inside Zip',
        });
        args.positional('output', {
            type: 'string',
            describe: 'Output Location',
        });
        return args;
    },
    handler: download,
})
    .help('help', 'Show help info.')
    .demandCommand()
    .recommendCommands()
    .strict()
    .fail((_msg, err) => {
    if (err)
        return console.log(err.message); // eslint-disable-line no-console
    return yargs.showHelp();
})
    .argv;
//# sourceMappingURL=partialzip.js.map