"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cross_fetch_1 = __importDefault(require("cross-fetch"));
const Zip_1 = __importDefault(require("./base/Zip"));
class PartialZip extends Zip_1.default {
    constructor(url, headers) {
        super(url);
        this.headers = headers || {};
    }
    async preInit() {
        const req = await cross_fetch_1.default(this.path, {
            method: 'HEAD',
            headers: this.headers,
        });
        if (req.status > 400) {
            throw new Error(`HTTP Error (${req.status}): ${req.statusText}`);
        }
        const acceptRanges = req.headers.get('accept-ranges');
        if (!acceptRanges || !acceptRanges.includes('bytes')) {
            throw new Error('Server does not support partial downloads');
        }
        const contentLength = req.headers.get('content-length');
        if (!contentLength) {
            throw new Error('Content-Length not found');
        }
        this.size = parseInt(contentLength, 10);
    }
    /**
     * Downloads part of a file from a url.
     *
     * @param start - start byte offset to get
     * @param end - end byte offset to get
     */
    async partialGet(start, end) {
        const req = await cross_fetch_1.default(this.path, {
            headers: {
                ...this.headers,
                Range: `bytes=${start}-${end}`,
            },
        });
        return Buffer.from(await req.arrayBuffer());
    }
}
exports.default = PartialZip;
//# sourceMappingURL=PartialZip.js.map