/// <reference types="node" />
import CentralDirectoryEntry from '../headers/CDEntry';
import EOCD from '../headers/EOCD';
import EOCD64 from '../headers/EOCD64';
import EOCD64Locator from '../headers/EOCD64Locator';
export default abstract class Zip {
    /**  Path/URL of Zip file */
    protected path: string;
    /** Zip size */
    protected size: number;
    /** EOCD */
    eocd?: EOCD;
    /** EOCD64 */
    eocd64?: EOCD64;
    /** EOCD64 Locator */
    eocd64Locator?: EOCD64Locator;
    /** Central Directory Entries */
    files: Map<string, CentralDirectoryEntry>;
    constructor(pathOrUrl: string);
    /**
     * Downloads part of a file from a url.
     *
     * @param start - start byte offset to get
     * @param end - end byte offset to get
     */
    abstract partialGet(start: number | bigint, end: number | bigint): Promise<Buffer>;
    /**
     * Any initialization needed like checking for partial download support
     * and file size initialization.
     * */
    protected abstract preInit(): Promise<void>;
    /**  */
    init(): Promise<void>;
    get(entry: CentralDirectoryEntry, checkIntegrity?: boolean): Promise<Buffer>;
    /** */
    protected getEocd(): Promise<void>;
    /** */
    protected getCentralDir(): Promise<void>;
}
//# sourceMappingURL=Zip.d.ts.map