"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HostOS = void 0;
const Entry_1 = __importDefault(require("../base/Entry"));
const InternalAttributes_1 = __importDefault(require("../bitfields/InternalAttributes"));
const Flags_1 = __importDefault(require("../bitfields/Flags"));
const ExtraField_1 = __importDefault(require("./ExtraField"));
var HostOS;
(function (HostOS) {
    HostOS[HostOS["MSDOS"] = 0] = "MSDOS";
    HostOS[HostOS["OS2"] = 0] = "OS2";
    HostOS[HostOS["AMIGA"] = 1] = "AMIGA";
    HostOS[HostOS["VMS"] = 2] = "VMS";
    HostOS[HostOS["UNIX"] = 3] = "UNIX";
    HostOS[HostOS["VM_CMS"] = 4] = "VM_CMS";
    HostOS[HostOS["ATARI_ST"] = 5] = "ATARI_ST";
    HostOS[HostOS["OS2_EFS"] = 6] = "OS2_EFS";
    HostOS[HostOS["MACINTOSH"] = 7] = "MACINTOSH";
})(HostOS = exports.HostOS || (exports.HostOS = {}));
class CentralDirectoryEntry extends Entry_1.default {
    constructor(buf) {
        super(buf);
        if (buf.readUInt32LE(0) !== CentralDirectoryEntry.signature) {
            throw new Error('Invalid Central Directory Entry');
        }
        this.version = buf.readUInt16LE(4);
        this.versionToExtract = buf.readUInt16LE(6);
        this.flags = new Flags_1.default(buf.readUInt16LE(8));
        this.compression = buf.readUInt16LE(10);
        this.lastModTime = buf.readUInt16LE(12);
        this.lastModDate = buf.readUInt16LE(14);
        this.crc32 = buf.readUInt32LE(16);
        this.compressedSize = buf.readUInt32LE(20);
        this.uncompressedSize = buf.readUInt32LE(24);
        this.fileNameLength = buf.readUInt16LE(28);
        this.extraFieldLength = buf.readUInt16LE(30);
        this.commentLength = buf.readUInt16LE(32);
        this.diskNo = buf.readUInt16LE(34);
        this.internalAttributes = new InternalAttributes_1.default(buf.readUInt16LE(36));
        this.externalAttributes = buf.readUInt32LE(38);
        this.offset = buf.readUInt32LE(42);
        this.fileName = buf.slice(46, 46 + this.fileNameLength).toString();
        const extraFieldOffset = 46 + this.fileNameLength;
        this.extraFieldRaw = buf.slice(extraFieldOffset, extraFieldOffset + this.extraFieldLength);
        this.extraField = new ExtraField_1.default(this.extraFieldRaw);
        const commentOffset = extraFieldOffset + this.extraFieldLength;
        this.comment = buf.slice(commentOffset, commentOffset + this.commentLength).toString();
    }
    get hostOS() {
        return this.version >> 8;
    }
    get zipVersion() {
        return this.version & 0xff;
    }
}
exports.default = CentralDirectoryEntry;
/** Central directory file header signature */
CentralDirectoryEntry.signature = 0x02014b50;
//# sourceMappingURL=CDEntry.js.map