"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Base_1 = __importDefault(require("../base/Base"));
class EOCD64 extends Base_1.default {
    constructor(buf) {
        const eocd = EOCD64.find(buf);
        if (!eocd)
            throw new Error('Zip64 EOCD not found');
        super(eocd);
        this.size = this.raw.readBigUInt64LE(4);
        // limit buffer to actual size
        this.version = this.raw.readUInt16LE(12);
        this.versionToExtract = this.raw.readUInt16LE(14);
        this.diskNo = this.raw.readUInt32LE(16);
        this.cdStart = this.raw.readUInt32LE(20);
        this.cdEntries = this.raw.readBigUInt64LE(24);
        this.cdTotal = this.raw.readBigUInt64LE(32);
        this.cdSize = this.raw.readBigUInt64LE(40);
        this.cdOffset = this.raw.readBigUInt64LE(48);
        this.extensibleDataSector = this.raw.slice(56, Number(this.size));
    }
    static find(buf) {
        // eslint-disable-next-line no-plusplus
        for (let i = buf.length - 22; i >= 0; i--) {
            if (buf.readUInt32LE(i) === EOCD64.signature) {
                return buf.slice(i);
            }
        }
        return false;
    }
}
exports.default = EOCD64;
/** Zip64 EOCD signature */
EOCD64.signature = 0x06064b50;
//# sourceMappingURL=EOCD64.js.map