"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Base_1 = __importDefault(require("../base/Base"));
class ExtraFields extends Base_1.default {
    constructor(buf) {
        super(buf);
        this.fields = [];
        let i = 0;
        while (i < buf.length - 3) {
            const id = buf.readUInt16LE(i);
            const size = buf.readUInt16LE(i + 2);
            const start = i + 4;
            const end = start + size;
            if (end > buf.length)
                throw new Error('Extra Field length exceeds buffer size');
            const data = buf.slice(start, end);
            this.fields.push({ id, data, length: size });
            i = end;
        }
    }
    get zip64() {
        const field = this.getField(0x0001);
        if (!field)
            return undefined;
        return {
            uncompressedSize: field.length >= 8 ? field.data.readBigUInt64LE(0) : BigInt(-1),
            compressedSize: field.length >= 16 ? field.data.readBigUInt64LE(8) : BigInt(-1),
            offset: field.length >= 24 ? field.data.readBigUInt64LE(16) : BigInt(-1),
            diskNo: field.length >= 28 ? field.data.readUInt32LE(24) : -1,
        };
    }
    getField(id) {
        const field = this.fields.find((x) => x.id === id);
        if (!field)
            return undefined;
        return field;
    }
}
exports.default = ExtraFields;
//# sourceMappingURL=ExtraField.js.map