"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.inflate = exports.bufferSplit = void 0;
const zlib_1 = require("zlib");
/**
 * Split a Buffer into an array of buffers using the specified separator.
 *
 * @param buf - Buffer to be split
 * @param separator - A buffer that is used in separating the buffer.
 * If omitted, a single-element array containing the entire buffer is returned.
 */
function bufferSplit(buf, separator) {
    const pieces = [];
    let i = 0;
    // eslint-disable-next-line no-cond-assign
    while ((i = buf.indexOf(separator, i)) > -1) {
        const end = buf.indexOf(separator, i + 1);
        // the undefined is for last elements
        pieces.push(buf.slice(i, end === -1 ? undefined : end));
        i = end;
    }
    return pieces;
}
exports.bufferSplit = bufferSplit;
/**
 * zlib inflate promisified
 *
 * @param buf - Buffer to inflate
 */
async function inflate(buf) {
    return new Promise((resolve, reject) => {
        zlib_1.inflateRaw(buf, (err, result) => {
            if (err)
                return reject(err);
            return resolve(result);
        });
    });
}
exports.inflate = inflate;
//# sourceMappingURL=index.js.map